@@ -152,6 +152,8 @@ from .ops import set_device
 from .ops import get_device
 from .ops import scatter_update
 from .ops import to_device
+from .ops import logsoftmax
+from .ops import roll
 # dtype
 from .ops import (
     DType, float16, float32, float64, int8, int16, int32, int64, uint8, uint16, uint32, uint64, bool, complex64,
