@@ -204,6 +204,8 @@ from .load_backend import set_device
 from .load_backend import get_device
 from .load_backend import scatter_update
 from .load_backend import to_device
+from .load_backend import roll
+from .load_backend import logsoftmax
 # dtype
 from .load_backend import (
     DType, float16, float32, float64, int8, int16, int32, int64, uint8, uint16, uint32, uint64, bool, complex64,
