@@ -1909,4 +1909,13 @@ def to_device(tensor, device = 'GPU', id = 0):
     if device == 'GPU':
         return paddle.to_tensor(tensor, place=paddle.CUDAPlace(id))
     if device == 'CPU':
-        return paddle.to_tensor(tensor, place=paddle.CPUPlace())
\ No newline at end of file
+        return paddle.to_tensor(tensor, place=paddle.CPUPlace())
+
+def roll(input, shifts, dims=None):
+
+    return paddle.roll(input, shifts, dims)
+
+def logsoftmax(input, dim = None):
+    if dim is None:
+        dim = -1
+    return F.log_softmax(input, dim)
\ No newline at end of file
