@@ -1250,15 +1250,15 @@ class BatchToSpace(object):
 
 class DepthToSpace(object):
 
-    def __init__(self, block_size, data_format='NHWC'):
+    def __init__(self, block_size, data_format):
         self.block_size = block_size
         self.data_format = data_format
 
     def __call__(self, input):
-        if self.data_format == 'NHWC':
+        if self.data_format == 'channels_last':
             input = nhwc_to_nchw(input)
         output = torch.nn.functional.pixel_shuffle(input, upscale_factor=self.block_size)
-        if  self.data_format == 'NHWC':
+        if self.data_format == 'channels_last':
             output = nchw_to_nhwc(output)
         return output
 
@@ -1726,4 +1726,13 @@ def to_device(tensor, device='GPU', id=0):
     if device == 'gpu':
         device = 'cuda' + ':' + str(id)
     tensor = tensor.detach().to(device)
-    return tensor
\ No newline at end of file
+    return tensor
+
+def roll(input, shifts, dims=None):
+
+    return torch.roll(input, shifts, dims)
+
+
+def logsoftmax(input, dim=None):
+
+    return F.log_softmax(input, dim)
\ No newline at end of file
