@@ -190,8 +190,8 @@ class Module(T_Module):
     def save_standard_weights(self, file_path):
         _save_standard_weights_dict(self, file_path)
 
-    def load_standard_weights(self, file_path, skip=False, reshape=False, format='npz_dict'):
-        _load_standard_weights_dict(self, file_path, skip, reshape, format)
+    def load_standard_weights(self, file_path, weights_from, weights_to, skip=False):
+        _load_standard_weights_dict(self, file_path, skip=skip, weights_from=weights_from, weights_to=weights_to)
 
     def str_to_init(self, initializer):
         return str2init(initializer)
@@ -207,11 +207,16 @@ class Module(T_Module):
 
         self.forward(*inputs, **kwargs)
 
+    def set_build_graph(self):
+        for layer_name, layer in self._modules.items():
+            if isinstance(layer, Module):
+                if len(layer._modules) > 1:
+                    layer.set_build_graph()
+                layer._build_graph = True
+
     def build_graph(self, *inputs, **kwargs):
         # Add nodes only when the composition is needed.
-        for name, layer in self._modules.items():
-            if isinstance(layer, Module):
-                layer._build_graph = True
+        self.set_build_graph()
         self.set_eval()
 
         outputs = self.forward(*inputs, **kwargs)
@@ -360,31 +365,26 @@ class Sequential(Module):
 
     def forward(self, input_data):
         for layer in self.layer_list:
-            inputs = input_data
             input_data = layer(input_data)
-            outputs = input_data
-            if not self._nodes_fixed and self._build_graph:
-                self._add_seq_node(inputs, outputs, layer)
-        self._nodes_fixed = True
         return input_data
 
-    def _add_seq_node(self, input_tensors, output_tensors, layer):
-        inputs_list = tolist(input_tensors)
-        outputs_list = tolist(output_tensors)
-        if layer.__class__.__name__ in tlx.layers.inputs.__all__:
-            in_nodes = []
-            in_tensor_idxes = [0]
-        else:
-            in_nodes = [tensor._info[0] for tensor in inputs_list]
-            in_tensor_idxes = [tensor._info[1] for tensor in inputs_list]
-        node_index = len(_global_layer_node)
-
-        new_node = ModuleNode(
-            layer, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(layer)
-        )
-        _global_layer_node.append(new_node)
-        for idx, tensor in enumerate(outputs_list):
-            tensor._info = (new_node, idx)
+    # def _add_seq_node(self, input_tensors, output_tensors, layer):
+    #     inputs_list = tolist(input_tensors)
+    #     outputs_list = tolist(output_tensors)
+    #     if layer.__class__.__name__ in tlx.layers.inputs.__all__:
+    #         in_nodes = []
+    #         in_tensor_idxes = [0]
+    #     else:
+    #         in_nodes = [tensor._info[0] for tensor in inputs_list]
+    #         in_tensor_idxes = [tensor._info[1] for tensor in inputs_list]
+    #     node_index = len(_global_layer_node)
+    #
+    #     new_node = ModuleNode(
+    #         layer, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(layer)
+    #     )
+    #     _global_layer_node.append(new_node)
+    #     for idx, tensor in enumerate(outputs_list):
+    #         tensor._info = (new_node, idx)
 
 
 class ModuleList(Module):
@@ -761,7 +761,6 @@ class ParameterDict(Module):
                         "ParameterDict update sequence element "
                         "#" + str(j) + " should be Iterable; is" + type(p).__name__
                     )
-                print(p)
                 if not len(p) == 2:
                     raise ValueError(
                         "ParameterDict update sequence element "
