@@ -5,8 +5,7 @@ import os
 import unittest
 
 os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
-
-import tensorlayer as tl
+import tensorlayerx as tlx
 
 from tests.utils import CustomTestCase
 
@@ -22,16 +21,16 @@ class Layer_Extend_Test(CustomTestCase):
         pass
 
     def test_expand_dims(self):
-        x = tl.layers.Input([8, 3])
-        expandlayer = tl.layers.ExpandDims(axis=-1)
+        x = tlx.nn.Input([8, 3])
+        expandlayer = tlx.nn.ExpandDims(axis=-1)
         y = expandlayer(x)
-        self.assertEqual(tl.get_tensor_shape(y), [8, 3, 1])
+        self.assertEqual(tlx.get_tensor_shape(y), [8, 3, 1])
 
     def test_tile(self):
-        x = tl.layers.Input([8, 3])
-        tilelayer = tl.layers.Tile(multiples=[2, 3])
+        x = tlx.nn.Input([8, 3])
+        tilelayer = tlx.nn.Tile(multiples=[2, 3])
         y = tilelayer(x)
-        self.assertEqual(tl.get_tensor_shape(y), [16, 9])
+        self.assertEqual(tlx.get_tensor_shape(y), [16, 9])
 
 
 if __name__ == '__main__':
